drop INDEX index_accounts;
drop INDEX index_courses;
drop INDEX index_fixed_info;
drop INDEX index_universityTable;
drop INDEX index_documents;

drop INDEX index_achievements;
drop INDEX index_extracurriculars;
drop INDEX index_skills;
drop INDEX index_projects;
drop INDEX index_submitted_resume;


drop table accounts;
drop table fixed_info;
drop table universityTable;
drop table documents;
drop table courses;

drop table achievements;
drop table extracurriculars;
drop table skills;
drop table projects;
drop table submitted_resume;

create table accounts (
    username varchar(20) PRIMARY KEY,
    password varchar(20) not null,
    acc_type varchar(4) not null
);

create table fixed_info(
    username varchar(20) PRIMARY KEY,
    rollno varchar(20) not null,
    fname varchar(20) not null,
    mname varchar(20),
    lname varchar(20) not null,
    dob date not null,
    sex varchar(6) not null
);

create table universityTable(
    rollno varchar(20) PRIMARY KEY,
    fname varchar(20) not null,
    lname varchar(20) not null,
    cpi numeric(3,2) not null,
    year varchar(20) not null,
    dept varchar(30) not null,
    course varchar(20) not null
);

create table documents(
    username varchar(20) not null,
    docname varchar(100) not null,
    doc bytea not null,
    PRIMARY KEY (username,docname)
);

create table courses(
    rno varchar(20) not null,
    courseid varchar(20) not null,
    coursename varchar(40) not null,
    PRIMARY KEY (rno,courseid)
);


insert into accounts values ('testuser1','testuser1','user');
insert into accounts values ('testuser2','testuser2','pc');
insert into accounts values ('jonsnow','jonsnow','user');
insert into accounts values ('dany','dany','user');
insert into accounts values ('eddardstark','eddardstark','user');
insert into accounts values ('a','a','user');
insert into accounts values ('b','b','user');

insert into fixed_info values ('testuser1','1300500tt','Test', 'Us', 'Er1','11-11-1995','male');
insert into fixed_info values ('testuser2','1300500tt2','Test',Null, 'User2','2-1-1995','female');
insert into fixed_info values ('jonsnow','1300500js','Jon','first of his name', 'Snow','2-1-1995','male');
insert into fixed_info values ('dany','1300500dt','Daenerys','stormborn', 'Targaryen','1-4-1995','female');
insert into fixed_info values ('eddardstark','1300500ns','Eddard',Null, 'Stark','2-1-1975','male');
insert into fixed_info values ('a','a','a','a', 'a','2-3-1994','male');
insert into fixed_info values ('b','b','b','b', 'b','12-4-1993','female');

insert into universityTable values('1300500tt','Test','Er1',8.55,'Third','CSE','B.Tech');
insert into universityTable values('1300500tt2','Test','User2',8.77,'Second','Chemistry','M.Sc.');
insert into universityTable values('a','a','a',8.77,'Second','Chemistry','M.Sc.');
insert into universityTable values('b','b','b',8.10,'Second','Chemistry','M.Sc.');
insert into universityTable values('c','c','c',9.11,'Second','Chemistry','M.Sc.');
insert into universityTable values('d','d','d',5.1,'Second','Chemistry','M.Sc.');
insert into universityTable values ('1300500js','Jon','Snow',7.1,'Second','Mechanical Engg.','M.Sc.');
insert into universityTable values ('1300500dt','Daenerys','Targaryen',9.99,'First','CSE','B.tech');
insert into universityTable values ('1300500ns','Eddard','Stark',7.8,'Fourth','CSE','Phd.');

insert into courses values('1300500tt','CS101','Computer Programming and Utilization');
insert into courses values('1300500tt','CS213','Data structure and Algorithm');
insert into courses values('1300500tt','CS218','Design and Analysis of Algorithm');
insert into courses values('1300500tt','CS317','Database and Information System');
insert into courses values('1300500tt2','CS101','Computer Programming and Utilization');
insert into courses values('1300500tt2','CS213','Data structure and Algorithm');
insert into courses values('1300500tt2','CS218','Design and Analysis of Algorithm');
insert into courses values('1300500tt2','CS317','Database and Information System');
insert into courses values('1300500tt2','HS101','Economics');
insert into courses values('a','CS218','Design and Analysis of Algorithm');
insert into courses values('a','CS101','Computer Programming and Utilization');
insert into courses values('b','CS317','Database and Information System');
insert into courses values('b','CS213','Data structure and Algorithm');
insert into courses values('c','CS317','Database and Information System');
insert into courses values('c','CS213','Data structure and Algorithm');
insert into courses values('d','CS317','Database and Information System');
insert into courses values('d','CS213','Data structure and Algorithm');
insert into courses values('1300500js','CS213','Data structure and Algorithm');
insert into courses values('1300500js','CS218','Design and Analysis of Algorithm');
insert into courses values('1300500js','CS317','Database and Information System');
insert into courses values('1300500dt','CS213','Data structure and Algorithm');
insert into courses values('1300500dt','CS218','Design and Analysis of Algorithm');
insert into courses values('1300500dt','CS317','Database and Information System');
insert into courses values('1300500ns','CS213','Data structure and Algorithm');
insert into courses values('1300500ns','CS218','Design and Analysis of Algorithm');
insert into courses values('1300500ns','CS317','Database and Information System');

create table achievements(
    username varchar(20) not null,
    version int not null,
    ord int not null,
    description varchar(256),
    time varchar(20),
    primary key (username,version,ord));

create table extracurriculars(
    username varchar(20) not null,
    version int not null,
    ord int not null,
    description varchar(256),
    time varchar(20),
    primary key (username,version,ord));

create table skills(
    username varchar(20) not null,
    version int not null,
    ord int not null,
    title varchar(256),
    description varchar(256),
    primary key (username,version,ord));

create table projects(
    username varchar(20) not null,
    version int not null,
    ord int not null,
    title varchar(60),
    time varchar(60),
    guide varchar(60),
    course varchar(60),
    d1 varchar(256),
    d2 varchar(256),
    d3 varchar(256),
    d4 varchar(256),
    primary key (username,version,ord));

create table submitted_resume(
    username varchar(20) not null,
    version int not null,
    resume bytea,
    verified varchar(1),
    remarks varchar(500),
    primary key (username,version));


CREATE INDEX index_accounts ON  accounts(username);
CREATE INDEX index_courses ON  courses(rno);
CREATE INDEX index_fixed_info ON  fixed_info(username);
CREATE INDEX index_universityTable ON  universityTable(rollno);
CREATE INDEX index_documents ON  documents(username);

CREATE INDEX index_achievements ON  achievements(username,version,ord);
CREATE INDEX index_extracurriculars ON  extracurriculars(username,version,ord);
CREATE INDEX index_skills ON  skills(username,version,ord);
CREATE INDEX index_projects ON  projects(username,version,ord);
CREATE INDEX index_submitted_resume ON  submitted_resume(username,version);
